using FalcoEngine;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Text.RegularExpressions;

public class GameManager : MonoBehaviour
{
    public static bool GameHasStarted = false;

    public AudioClip WinSound;
    public AudioClip GameOverSound;
	public GameObject Player;
	public GameObject InfoPanel;
	public Text LevelText;
    public Text WinText;
    public Text GameOverText;
	
	private CursorController _cursorController;
    private bool _canLoadNextLevel = false;
    private float _timerToLoadNextLevel = 0;

    private bool _canRestartLevel = false;
    private float _timerRestartLevel = 0;
    private int _currentLevel = 1;
   
    void Start()
    {
        _currentLevel = Convert.ToInt32(Regex.Replace(SceneManager.loadedScene, @"[^\d]+", ""));
        _cursorController = FindObjectOfType<CursorController>();
        LevelText.text = "Level: " + _currentLevel.ToString();
    }

    void Update()
	{
        if (Input.GetKeyDown(ScanCode.Space) & GameHasStarted == false)
        {
            GameStart();
        }

        if (_canLoadNextLevel == true)
        {
            if (_timerToLoadNextLevel > 1)
            {
                SceneManager.LoadScene($"{_currentLevel + 1}.scene");
                _canLoadNextLevel = false;
            }
            else
            {
                _timerToLoadNextLevel += Time.deltaTime;
            }
        }

        if (_canRestartLevel == true)
        {
            if (_timerRestartLevel > 1)
            {
                SceneManager.LoadScene(SceneManager.loadedScene);
                _canRestartLevel = false;
            }
            else
            {
              _timerRestartLevel += Time.deltaTime;
            }
        }
    }

	public void GameStart()
	{
        GameHasStarted = false;
        _cursorController.HideCursorObj();
		InfoPanel.enabled = false;
        Player.rigidbody.isKinematic = false;
		GameHasStarted = true;
	}

    public void LoadNextLevel()
    {
        GameHasStarted = false;
        WinText.enabled = true;
        _canLoadNextLevel = true;
        PlaySound(WinSound);
    }

    public void Restart()
    {
        GameOverText.enabled = true;
        _canRestartLevel = true;
        PlaySound(GameOverSound);
    }
    private void PlaySound(AudioClip sound)
    {
        audioSource.audioClip = sound;
        audioSource.Play();
    }
}
